"use strict";(self.webpackChunkihighlight=self.webpackChunkihighlight||[]).push([[509],{509:(e,o,s)=>{s.r(o),s.d(o,{default:()=>r});var l=s(256),t=s(707),d=s(933);const r={id:"icomplexity:plugin",description:"An analytic complexity calculator jupyter lab/nb extension",autoStart:!0,requires:[],activate:async(e,o,s)=>{let r;if(document.querySelector(".jp-ilambda-Anchor")||(r=document.createElement("div"),r.innerHTML="<a href='https://www.lambda.joburg' target='_blank'><img src='https://lambda.joburg/assets/images/index/logo/lambda_logo.svg'></a>"),r){const o=new l.Widget({node:r});o.addClass("jp-ilambda-Anchor"),o.id=t.DOMUtils.createDomID(),e.shell.add(o,"top",{rank:1e3})}d.NotebookActions.executionScheduled.connect(((e,o)=>{var s,l,t;const{cell:d}=o;if("code"===d.model.type){let e=d.editorWidget;if(null===(s=d.inputArea)||void 0===s||s.promptNode.classList.remove("prompt-node-success"),null===(l=d.inputArea)||void 0===l||l.promptNode.classList.remove("prompt-node-error"),null==e||e.removeClass("editor-success"),null==e||e.removeClass("editor-error"),""!==d.model.sharedModel.source){let o=null===(t=d.inputArea)||void 0===t?void 0:t.promptNode;null==o||o.classList.add("prompt-node-scheduled"),null==e||e.addClass("editor-scheduled")}}})),d.NotebookActions.executed.connect(((e,o)=>{var s,l,t,d,r;const{cell:i}=o,{success:a}=o;if("code"==i.model.type){let e=i.editorWidget;null===(s=i.inputArea)||void 0===s||s.promptNode.classList.remove("prompt-node-error"),null===(l=i.inputArea)||void 0===l||l.promptNode.classList.remove("prompt-node-success"),null===(t=i.inputArea)||void 0===t||t.promptNode.classList.remove("prompt-node-scheduled"),null==e||e.removeClass("editor-error"),null==e||e.removeClass("editor-scheduled"),null==e||e.removeClass("editor-success"),a?""!==i.model.sharedModel.source&&(null===(d=i.inputArea)||void 0===d||d.promptNode.classList.add("prompt-node-success"),null==e||e.addClass("editor-success")):(null===(r=i.inputArea)||void 0===r||r.promptNode.classList.add("prompt-node-error"),null==e||e.addClass("editor-error"))}}))}}}}]);